# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/nbstata',
                'doc_host': 'https://hugetim.github.io',
                'git_url': 'https://github.com/hugetim/nbstata',
                'lib_path': 'nbstata'},
  'syms': { 'nbstata.config': { 'nbstata.config.find_dir_edition': ('config.html#find_dir_edition', 'nbstata/config.py'),
                                'nbstata.config.find_path': ('config.html#find_path', 'nbstata/config.py'),
                                'nbstata.config.get_config': ('config.html#get_config', 'nbstata/config.py'),
                                'nbstata.config.launch_stata': ('config.html#launch_stata', 'nbstata/config.py'),
                                'nbstata.config.mac_find_path': ('config.html#mac_find_path', 'nbstata/config.py'),
                                'nbstata.config.set_pystata_path': ('config.html#set_pystata_path', 'nbstata/config.py'),
                                'nbstata.config.win_find_path': ('config.html#win_find_path', 'nbstata/config.py')},
            'nbstata.helpers': { 'nbstata.helpers.Selectvar': ('helpers.html#selectvar', 'nbstata/helpers.py'),
                                 'nbstata.helpers.Selectvar.__init__': ('helpers.html#selectvar.__init__', 'nbstata/helpers.py'),
                                 'nbstata.helpers.Selectvar.clear': ('helpers.html#selectvar.clear', 'nbstata/helpers.py'),
                                 'nbstata.helpers._run_as_program': ('helpers.html#_run_as_program', 'nbstata/helpers.py'),
                                 'nbstata.helpers.better_dataframe_from_stata': ( 'helpers.html#better_dataframe_from_stata',
                                                                                  'nbstata/helpers.py'),
                                 'nbstata.helpers.better_pdataframe_from_data': ( 'helpers.html#better_pdataframe_from_data',
                                                                                  'nbstata/helpers.py'),
                                 'nbstata.helpers.better_pdataframe_from_frame': ( 'helpers.html#better_pdataframe_from_frame',
                                                                                   'nbstata/helpers.py'),
                                 'nbstata.helpers.count': ('helpers.html#count', 'nbstata/helpers.py'),
                                 'nbstata.helpers.resolve_macro': ('helpers.html#resolve_macro', 'nbstata/helpers.py'),
                                 'nbstata.helpers.run_noecho': ('helpers.html#run_noecho', 'nbstata/helpers.py'),
                                 'nbstata.helpers.run_non_prog_noecho': ('helpers.html#run_non_prog_noecho', 'nbstata/helpers.py'),
                                 'nbstata.helpers.run_prog_noecho': ('helpers.html#run_prog_noecho', 'nbstata/helpers.py')},
            'nbstata.install': {},
            'nbstata.kernel': { 'nbstata.kernel.Cell': ('kernel.html#cell', 'nbstata/kernel.py'),
                                'nbstata.kernel.Cell.__init__': ('kernel.html#cell.__init__', 'nbstata/kernel.py'),
                                'nbstata.kernel.Cell.run': ('kernel.html#cell.run', 'nbstata/kernel.py'),
                                'nbstata.kernel.PyStataKernel': ('kernel.html#pystatakernel', 'nbstata/kernel.py'),
                                'nbstata.kernel.PyStataKernel.__init__': ('kernel.html#pystatakernel.__init__', 'nbstata/kernel.py'),
                                'nbstata.kernel.PyStataKernel.do_execute': ('kernel.html#pystatakernel.do_execute', 'nbstata/kernel.py'),
                                'nbstata.kernel.PyStataKernel.init_stata': ('kernel.html#pystatakernel.init_stata', 'nbstata/kernel.py'),
                                'nbstata.kernel._handle_error': ('kernel.html#_handle_error', 'nbstata/kernel.py'),
                                'nbstata.kernel.print_stata_error': ('kernel.html#print_stata_error', 'nbstata/kernel.py')},
            'nbstata.magics': { 'nbstata.magics.StataMagics': ('magics.html#statamagics', 'nbstata/magics.py'),
                                'nbstata.magics.StataMagics.magic': ('magics.html#statamagics.magic', 'nbstata/magics.py'),
                                'nbstata.magics.StataMagics.magic_browse': ('magics.html#statamagics.magic_browse', 'nbstata/magics.py'),
                                'nbstata.magics.StataMagics.magic_echo': ('magics.html#statamagics.magic_echo', 'nbstata/magics.py'),
                                'nbstata.magics.StataMagics.magic_help': ('magics.html#statamagics.magic_help', 'nbstata/magics.py'),
                                'nbstata.magics.StataMagics.magic_noecho': ('magics.html#statamagics.magic_noecho', 'nbstata/magics.py'),
                                'nbstata.magics.StataMagics.magic_quietly': ('magics.html#statamagics.magic_quietly', 'nbstata/magics.py'),
                                'nbstata.magics.print_kernel': ('magics.html#print_kernel', 'nbstata/magics.py')},
            'nbstata.utils': { 'nbstata.utils.HiddenPrints': ('utils.html#hiddenprints', 'nbstata/utils.py'),
                               'nbstata.utils.HiddenPrints.__enter__': ('utils.html#hiddenprints.__enter__', 'nbstata/utils.py'),
                               'nbstata.utils.HiddenPrints.__exit__': ('utils.html#hiddenprints.__exit__', 'nbstata/utils.py'),
                               'nbstata.utils._remove_multi_line_comments': ('utils.html#_remove_multi_line_comments', 'nbstata/utils.py'),
                               'nbstata.utils._remove_prog_prefixes': ('utils.html#_remove_prog_prefixes', 'nbstata/utils.py'),
                               'nbstata.utils._replace_delimiter': ('utils.html#_replace_delimiter', 'nbstata/utils.py'),
                               'nbstata.utils._startswith_stata_abbrev': ('utils.html#_startswith_stata_abbrev', 'nbstata/utils.py'),
                               'nbstata.utils.break_out_prog_blocks': ('utils.html#break_out_prog_blocks', 'nbstata/utils.py'),
                               'nbstata.utils.ending_delimiter': ('utils.html#ending_delimiter', 'nbstata/utils.py'),
                               'nbstata.utils.in_range': ('utils.html#in_range', 'nbstata/utils.py'),
                               'nbstata.utils.is_cr_delimiter': ('utils.html#is_cr_delimiter', 'nbstata/utils.py'),
                               'nbstata.utils.is_start_of_program_block': ('utils.html#is_start_of_program_block', 'nbstata/utils.py'),
                               'nbstata.utils.parse_code_if_in': ('utils.html#parse_code_if_in', 'nbstata/utils.py'),
                               'nbstata.utils.print_red': ('utils.html#print_red', 'nbstata/utils.py'),
                               'nbstata.utils.standardize_code': ('utils.html#standardize_code', 'nbstata/utils.py')}}}
